#!/usr/bin/env node
"use strict";

require("core-js/modules/es.promise.js");

require("core-js/modules/es.regexp.constructor.js");

require("core-js/modules/es.regexp.exec.js");

require("core-js/modules/es.regexp.to-string.js");

require("core-js/modules/es.array.reduce.js");

require("core-js/modules/es.array.flat.js");

require("core-js/modules/es.array.unscopables.flat.js");

var _fs = _interopRequireDefault(require("fs"));

var _processing = require("./utils/processing");

var _finders = require("./utils/finders");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const TARGET_FILE_NAME = 'index.json';
/**
 * Main
 */

async function main() {
  // expectation is a file directory like the following

  /*
    TV
      Community
        Season (1)
          Episode (1).mkv
          Episode (2).mkv
          ...
        Season (2)
          ...
        index.json
      Parks and Recreation
        Season (1)
          Episode (1).mp4
          Episode (2).mp4
        Season (2)
          ...
        index.json
  */
  const findIndexFilesRegex = new RegExp(TARGET_FILE_NAME, 'g');
  const tvShowInputData = (0, _finders.findWithFilter)('./', findIndexFilesRegex).reduce((acc, path) => {
    const rootPath = (0, _finders.getRootPathItem)("".concat(process.cwd(), "/").concat(path));
    const showName = (0, _finders.getLastPathItem)(rootPath);
    const imdbId = JSON.parse(_fs.default.readFileSync(path, 'utf8')).id;
    return _objectSpread(_objectSpread({}, acc), {}, {
      [showName]: {
        tvShowRootPath: rootPath,
        indexPath: path,
        imdbId
      }
    });
  }, {});
  console.log('Starting to rename seasons...');
  await (0, _processing.renameSeasons)(tvShowInputData);
  const tvShowInputDataWithSeasonNumbers = await (0, _processing.addNumberOfSeasonsToInput)(tvShowInputData);
  const tvShowInputDataWithEpisodeNames = await (0, _processing.addEpisodeNamesToInput)(tvShowInputDataWithSeasonNumbers);
  const pathsWithEpisodeNames = (0, _processing.getEpisodePathsWithEpisodeNames)(tvShowInputDataWithEpisodeNames);
  console.log('Starting to rename episodes...');
  await (0, _processing.renameEpisodes)(pathsWithEpisodeNames.flat(1));
}

main();