"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getEpisodeNames = getEpisodeNames;
exports.getNumSeries = getNumSeries;
exports.getSeriesLink = getSeriesLink;

require("core-js/modules/es.promise.js");

var _curl = _interopRequireDefault(require("curl"));

var _cheerio = _interopRequireDefault(require("cheerio"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable */

/**
 * Utility to get an IMDb link which points to the episode list for
 * a given season of a show
 *
 * @param {number} seriesIndex The series number to get a link for
 * @param {string} seriesId The ID of the series to get a link for
 *
 * @returns {string} The URL to find episode information for
 */
function getSeriesLink(seriesIndex, seriesId) {
  return "https://www.imdb.com/title/".concat(seriesId, "/episodes?season=").concat(seriesIndex);
}

function getNumSeries(seriesLink) {
  return new Promise((resolve, reject) => {
    _curl.default.get(seriesLink, (err, response, body) => {
      try {
        const $ = _cheerio.default.load(body);

        const seasonNumbers = $('#bySeason option').map((_, element) => $(element).text()).get().length;
        resolve(seasonNumbers);
      } catch (error) {
        reject(new Error("Could not grab number of pages needed from page: ".concat(seriesLink, ", error: ").concat(error)));
      }
    });
  });
}
/**
 * Method to get episode names from an IMDb page
 *
 * @param {string} seriesLink The link to find episode names from
 * @returns {Array<string>} An array of episode names
 */


async function getEpisodeNames(seriesLink) {
  return new Promise((resolve, reject) => {
    _curl.default.get(seriesLink, (err, response, body) => {
      try {
        const $ = _cheerio.default.load(body);

        const episodeNames = $('.eplist .info strong').map((_, element) => $(element).text()).get();
        resolve(episodeNames);
      } catch (error) {
        reject(new Error("Could not grab number of pages needed from page: ".concat(seriesLink, ", error: ").concat(error)));
      }
    });
  });
}